@@ -1,4 +1,5 @@
-(* Copyright (C) 2000, Luca Padovani <luca.padovani@cs.unibo.it>.
+(* Copyright (C) 2000-2003, Luca Padovani <luca.padovani@cs.unibo.it>,
+ *                          Claudio Sacerdoti Coen <sacerdot@cs.unibo.it>.
  *
  * This file is part of lablgtkmathview, the Ocaml binding
  * for the GtkMathView widget.
@@ -20,4 +21,4 @@
  * For details, send a mail to the author.
  *)
 
-type math_view = [`widget|`container|`bin|`eventbox|`math_view]
+type math_view = [Gtk.event_box|`mathview]
